"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const plugin_syntax_jsx_1 = __importDefault(require("@babel/plugin-syntax-jsx"));
const core_1 = require("@babel/core");
const CLSX_IGNORE_GLOBAL_TOKEN = '@clsx-ignore-global';
const CLSX_IGNORE_TOKEN = '@clsx-ignore';
const CLASS_NAME_STRICT_RE = /^className$/;
const CLASS_NAME_RE = /^(className|\w+ClassName)$/;
const IMPORT_SOURCE = 'clsx';
const IMPORT_NAME = 'default';
const IMPORT_NAMESPACE = '_clsx';
exports.default = (_, opts = {}) => {
    opts.strict = typeof opts.strict === 'boolean' ? opts.strict : true;
    opts.importSource = opts.importSource || IMPORT_SOURCE;
    opts.importName = opts.importName || IMPORT_NAME;
    const callId = core_1.types.identifier(IMPORT_NAMESPACE);
    const importId = opts.importName === IMPORT_NAME
        ? core_1.types.importDefaultSpecifier(callId)
        : core_1.types.importSpecifier(callId, core_1.types.identifier(opts.importName));
    const importDecl = core_1.types.importDeclaration([importId], core_1.types.stringLiteral(opts.importSource));
    function isIgnoredGlobal(nodes) {
        return nodes.some((item) => isIgnored(item, CLSX_IGNORE_GLOBAL_TOKEN));
    }
    function isIgnored(node, token = CLSX_IGNORE_TOKEN) {
        return node.leadingComments
            ? node.leadingComments.some((comment) => {
                const ignored = comment.value.trim() === token;
                if (ignored)
                    comment.ignore = ignored;
                return ignored;
            })
            : false;
    }
    const classNameRE = opts.strict ? CLASS_NAME_STRICT_RE : CLASS_NAME_RE;
    function isDynamicClassName(node) {
        return (classNameRE.test(node.name.name) &&
            core_1.types.isJSXExpressionContainer(node.value) &&
            !core_1.types.isStringLiteral(node.value.expression));
    }
    function importLibrary(state) {
        if (!state.clsxImported) {
            state.clsxImported = true;
            getFileBody(state.file).unshift(importDecl);
        }
    }
    function getFileBody(file) {
        return file.path.node.body;
    }
    function replaceNode(path) {
        const callExpr = core_1.types.callExpression(callId, [path.node]);
        path.replaceWith(callExpr);
    }
    return {
        name: 'clsx',
        inherits: plugin_syntax_jsx_1.default,
        pre(file) {
            this.clsxIgnoreGlobal = isIgnoredGlobal(getFileBody(file));
        },
        visitor: {
            JSXAttribute(path) {
                if (isDynamicClassName(path.node) &&
                    !isIgnored(path.node) &&
                    !this.clsxIgnoreGlobal) {
                    importLibrary(this);
                    replaceNode(path.get('value').get('expression'));
                }
            },
        },
    };
};
//# sourceMappingURL=index.js.map